"""
NGI Live Python SDK documentation.

Click `View Source` to expand source code for each method.


**Installation**

```bash
pip install ngilive
```
"""

from ngilive.api import NGILive
from ngilive.auth import AuthorizationCode, ClientCredentials

__all__ = ["NGILive", "AuthorizationCode", "ClientCredentials"]
